@@ -1,5 +1,7 @@
 from .superobs_sqlite import compute_average
 from .fill_ray        import fill_ray_dict
 from .superobs_sqlite import find_schema
-from .evaluation import radvelso_evaluation_sqlite
-from .evaluation import radvelso_evaluation_sqlite_plot
+from .evaluation import *
+from .cthinning import *
+from .qcavg import *
+from .unravel import *
